@@ -49,11 +49,33 @@ class EmbeddingConfig:
     
     # Background embedding refresh settings
     enable_background_refresh: bool = True
-    background_refresh_interval: int = 600  # Refresh embeddings every 10 minutes (600 seconds)
+    # Refresh embeddings every 12 hours by default
+    background_refresh_interval: int = 43200
+    # TTL for cached staff embeddings (controls on-demand refresh checks)
+    staff_embeddings_cache_ttl: int = 43200
 
 
 class EmbeddingManager:
-    """Manages face embeddings, search operations, and caching."""
+    """
+    Manages face embeddings, search operations, and caching.
+    
+    CRITICAL INITIALIZATION FLOW:
+    1. __init__() creates the manager but does NOT load embeddings or start background refresh
+    2. External caller MUST call await _load_staff_embeddings() to load embeddings synchronously
+    3. After successful load, caller SHOULD call start_background_refresh() for periodic updates
+    4. The _embeddings_loaded flag tracks whether embeddings are ready for use
+    5. All search operations check _embeddings_loaded before proceeding
+    
+    This design prevents race conditions where:
+    - Background thread tries to load while main thread is loading
+    - Search operations are called before embeddings are loaded
+    - Multiple threads compete for the embeddings_lock during initialization
+    
+    Thread Safety:
+    - _embeddings_lock protects embeddings_matrix and embedding_metadata
+    - _cache_lock protects track_id_cache
+    - _embeddings_loaded is set only after successful load under lock
+    """
     
     def __init__(self, config: EmbeddingConfig, face_client: FacialRecognitionClient = None):
         self.config = config
@@ -67,7 +89,8 @@ class EmbeddingManager:
         # Staff embeddings cache for local similarity search
         self.staff_embeddings: List[StaffEmbedding] = []
         self.staff_embeddings_last_update = 0
-        self.staff_embeddings_cache_ttl = 3600  # 1 hour
+        # Use configured TTL (default: 12 hours)
+        self.staff_embeddings_cache_ttl = int(self.config.staff_embeddings_cache_ttl)
         
         # Numpy arrays for fast similarity computation
         self.embeddings_matrix = None
@@ -85,11 +108,47 @@ class EmbeddingManager:
         self._is_running = False
         self._stop_event = threading.Event()
         
-        # Start background refresh if enabled
-        if self.config.enable_background_refresh and self.face_client:
-            self.start_background_refresh()
-            self.logger.info(f"Background embedding refresh enabled - interval: {self.config.background_refresh_interval}s")
+        # Initialization status flag
+        self._embeddings_loaded = False
         
+        # DON'T start background refresh yet - wait for initial load in initialize()
+        # This prevents race conditions where background thread interferes with main init
+        self.logger.info(f"EmbeddingManager created - background refresh will start after initial load (interval: {self.config.background_refresh_interval}s)")
+        
+    def is_ready(self) -> bool:
+        """
+        Check if embeddings are loaded and ready for use.
+        
+        Returns:
+            True if embeddings are loaded and matrix is valid, False otherwise
+        """
+        return (
+            self._embeddings_loaded 
+            and self.embeddings_matrix is not None 
+            and len(self.embedding_metadata) > 0
+        )
+    
+    def get_status(self) -> Dict[str, Any]:
+        """
+        Get detailed status of embedding manager for debugging and health checks.
+        
+        Returns:
+            Dictionary with status information
+        """
+        with self._embeddings_lock:
+            matrix_shape = self.embeddings_matrix.shape if self.embeddings_matrix is not None else None
+            
+        return {
+            "embeddings_loaded": self._embeddings_loaded,
+            "embeddings_count": len(self.staff_embeddings),
+            "matrix_shape": matrix_shape,
+            "metadata_count": len(self.embedding_metadata),
+            "cache_size": len(self.track_id_cache),
+            "last_update": self.staff_embeddings_last_update,
+            "is_running": self._is_running,
+            "is_ready": self.is_ready(),
+        }
+    
     def set_face_client(self, face_client: FacialRecognitionClient):
         """Set the face recognition client."""
         self.face_client = face_client
@@ -171,39 +230,91 @@ class EmbeddingManager:
         """Load all staff embeddings from API and cache them."""
         if not self.face_client:
             self.logger.error("Face client not available for loading staff embeddings")
+            print("ERROR: Face client not available for loading staff embeddings")
             return False
             
         try:
-            self.logger.info("Loading staff embeddings from API...")
+            #self.logger.info("Loading staff embeddings from API...")
+            #print("=============== LOADING STAFF EMBEDDINGS FROM API ===============")
             response = await self.face_client.get_all_staff_embeddings()
+            #print(f"API RESPONSE TYPE: {type(response)}, IS_LIST: {isinstance(response, list)}, LEN: {len(response) if isinstance(response, list) else 'N/A'}")
             
-            if not response.get("success", False):
-                self.logger.error(f"Failed to get staff embeddings from API: {response.get('error', 'Unknown error')}")
+            # Robust response handling: accept dict with data or raw list
+            embeddings_data: List[Dict[str, Any]] = []
+            if isinstance(response, dict):
+                # Typical: { success: True, data: [...] }
+                if response.get("success", False) and isinstance(response.get("data"), list):
+                    embeddings_data = response.get("data", [])
+                # Alternate: { data: [...] } without success flag
+                elif isinstance(response.get("data"), list):
+                    embeddings_data = response.get("data", [])
+                # Fallback keys sometimes used
+                elif isinstance(response.get("items"), list):
+                    embeddings_data = response.get("items", [])
+                else:
+                    self.logger.error(f"Unexpected embeddings response shape (dict): keys={list(response.keys())}")
+                    return False
+            elif isinstance(response, list):
+                # Some deployments return raw list directly
+                embeddings_data = response
+            else:
+                self.logger.error(f"Unexpected embeddings response type: {type(response)}")
                 return False
-                
-            # The API response has the format: {"success": True, "data": [embedding_items]}
-            # Each item has the structure shown in the sample response
-            embeddings_data = response.get("data", [])
             
             self.staff_embeddings = []
             embeddings_list = []
-            
+            expected_dim: Optional[int] = None
+            dims_observed: List[int] = []
+            mismatch_examples: List[Tuple[str, int]] = []  # (staffId, dim)
+
             for item in embeddings_data:
-                # if not item.get("isActive", True): # TODO: Check what is isActive
-                #     continue
-                    
+                # Skip inactive if provided
+                if isinstance(item, dict) and item.get("isActive") is False:
+                    continue
+
+                raw_emb = []
+                try:
+                    raw_emb = item.get("embedding", []) if isinstance(item, dict) else []
+                except Exception:
+                    raw_emb = []
+                # Record observed dimension for debugging
+                try:
+                    dims_observed.append(len(raw_emb) if isinstance(raw_emb, list) else 0)
+                except Exception:
+                    dims_observed.append(0)
+
+                # Validate and coerce embedding list
+                if not isinstance(raw_emb, list) or len(raw_emb) == 0:
+                    continue
+                try:
+                    # Ensure numeric float32 list
+                    clean_emb = [float(v) for v in raw_emb]
+                except Exception:
+                    continue
+
+                # Dimension consistency
+                if expected_dim is None:
+                    expected_dim = len(clean_emb)
+                if len(clean_emb) != expected_dim:
+                    # Collect a few examples to aid debugging
+                    try:
+                        mismatch_examples.append((str(item.get("staffId", "")), len(clean_emb)))
+                    except Exception:
+                        mismatch_examples.append(("", len(clean_emb)))
+                    self.logger.warning(f"Skipping embedding with mismatched dimension: got {len(clean_emb)} expected {expected_dim}")
+                    continue
+
                 staff_embedding = StaffEmbedding(
-                    embedding_id=item.get("embeddingId", ""),
-                    staff_id=item.get("staffId", ""),
-                    embedding=item.get("embedding", []),
-                    employee_id=str(item.get("employeeId", "")),
-                    staff_details=item.get("staffDetails", {}),
-                    is_active=item.get("isActive", True)
+                    embedding_id=(item.get("embeddingId", "") if isinstance(item, dict) else ""),
+                    staff_id=(item.get("staffId", "") if isinstance(item, dict) else ""),
+                    embedding=clean_emb,
+                    employee_id=str(item.get("employeeId", "")) if isinstance(item, dict) else "",
+                    staff_details=(item.get("staffDetails", {}) if isinstance(item, dict) else {}),
+                    is_active=(item.get("isActive", True) if isinstance(item, dict) else True)
                 )
-                
-                if staff_embedding.embedding:  # Only add if embedding exists
-                    self.staff_embeddings.append(staff_embedding)
-                    embeddings_list.append(staff_embedding.embedding)
+
+                self.staff_embeddings.append(staff_embedding)
+                embeddings_list.append(clean_emb)
             
             # Create numpy matrix for fast similarity computation (thread-safe)
             with self._embeddings_lock:
@@ -216,12 +327,33 @@ class EmbeddingManager:
                     
                     self.embedding_metadata = self.staff_embeddings.copy()
                     self.staff_embeddings_last_update = time.time()
-                    self.logger.info(f"Successfully loaded and cached {len(self.staff_embeddings)} staff embeddings")
-                    self.logger.debug(f"Embeddings matrix shape: {self.embeddings_matrix.shape}")
+                    self._embeddings_loaded = True  # Mark as successfully loaded
+                    
+                    self.logger.info(f"Successfully loaded and cached {len(self.staff_embeddings)} staff embeddings (dim={self.embeddings_matrix.shape[1]})")
+                    #print(f"=============== SUCCESS: LOADED {len(self.staff_embeddings)} EMBEDDINGS, MATRIX SHAPE: {self.embeddings_matrix.shape} ===============")
+                    try:
+                        # Quick sanity metrics
+                        row0_sum = float(np.sum(self.embeddings_matrix[0])) if self.embeddings_matrix.shape[0] > 0 else 0.0
+                        row0_norm = float(np.linalg.norm(self.embeddings_matrix[0])) if self.embeddings_matrix.shape[0] > 0 else 0.0
+                        #print(f"SANITY CHECK: row0_sum={row0_sum:.4f}, row0_norm={row0_norm:.4f} (should be ~1.0 after normalization)")
+                        #self.logger.debug(f"Embeddings matrix shape: {self.embeddings_matrix.shape}, dtype={self.embeddings_matrix.dtype}, row0_sum={row0_sum:.4f}")
+                    except Exception as e:
+                        print(f"ERROR in sanity check: {e}")
                     return True
                 else:
-                    self.logger.warning("No active staff embeddings found in API response")
-                    return False
+                    # Build diagnostics and raise to stop pipeline early with actionable info
+                    dims_summary: Dict[int, int] = {}
+                    for d in dims_observed:
+                        dims_summary[d] = dims_summary.get(d, 0) + 1
+                    error_msg = (
+                        f"No valid staff embeddings loaded. Observed dimension distribution: {dims_summary}. "
+                        f"Expected_dim={expected_dim}. Mismatch examples (staffId, dim): {mismatch_examples[:5]}"
+                    )
+                    self.logger.error(error_msg)
+                    print(f"=============== ERROR: NO VALID EMBEDDINGS ===============")
+                    print(f"ERROR: {error_msg}")
+                    print(f"=============== STOPPING PIPELINE ===============")
+                    raise RuntimeError(f"Failed to load staff embeddings due to dimension mismatch. Observed dims: {dims_summary}")
                 
         except Exception as e:
             self.logger.error(f"Error loading staff embeddings: {e}", exc_info=True)
@@ -261,8 +393,16 @@ class EmbeddingManager:
     
     def _find_best_local_match(self, query_embedding: List[float]) -> Optional[Tuple[StaffEmbedding, float]]:
         """Find best matching staff member using optimized matrix operations (thread-safe)."""
+        # Check if embeddings are loaded at all
+        if not self._embeddings_loaded:
+            #print(f"ERROR: _find_best_local_match called but embeddings not loaded yet (_embeddings_loaded={self._embeddings_loaded})")
+            self.logger.error("Embeddings not loaded - _find_best_local_match cannot proceed")
+            return None
+            
         with self._embeddings_lock:
             if self.embeddings_matrix is None or len(self.embedding_metadata) == 0:
+                #print(f"ERROR: _find_best_local_match - embeddings_matrix is None={self.embeddings_matrix is None}, metadata_len={len(self.embedding_metadata)}, _embeddings_loaded={self._embeddings_loaded}")
+                self.logger.error(f"Embeddings matrix is None despite _embeddings_loaded={self._embeddings_loaded}")
                 return None
                 
             # Create local copies to avoid issues with concurrent modifications
@@ -270,10 +410,16 @@ class EmbeddingManager:
             embedding_metadata = self.embedding_metadata.copy()
             
         if embeddings_matrix is None:
+            print("ERROR: _find_best_local_match - embeddings_matrix copy is None")
             return None
             
         try:
             query_array = np.array(query_embedding, dtype=np.float32).reshape(1, -1)
+            # Dimension check
+            if embeddings_matrix.shape[1] != query_array.shape[1]:
+                self.logger.warning(f"Query embedding dim mismatch: query={query_array.shape[1]} staff={embeddings_matrix.shape[1]}")
+                print(f"ERROR: DIMENSION MISMATCH - query={query_array.shape[1]} staff={embeddings_matrix.shape[1]}")
+                return None
             
             # Normalize query embedding
             query_norm = np.linalg.norm(query_array)
@@ -298,6 +444,28 @@ class EmbeddingManager:
         except Exception as e:
             self.logger.error(f"Error in local similarity search: {e}", exc_info=True)
             return None
+
+    def get_best_similarity(self, query_embedding: List[float]) -> float:
+        """Return the best cosine similarity for debugging/observability (no threshold gating)."""
+        with self._embeddings_lock:
+            if self.embeddings_matrix is None or len(self.embedding_metadata) == 0:
+                return 0.0
+            embeddings_matrix = self.embeddings_matrix.copy() if self.embeddings_matrix is not None else None
+        if embeddings_matrix is None:
+            return 0.0
+        try:
+            query_array = np.array(query_embedding, dtype=np.float32).reshape(1, -1)
+            if embeddings_matrix.shape[1] != query_array.shape[1]:
+                print(f"ERROR: get_best_similarity DIMENSION MISMATCH - query={query_array.shape[1]} staff={embeddings_matrix.shape[1]}")
+                return 0.0
+            qn = np.linalg.norm(query_array)
+            if qn == 0:
+                return 0.0
+            query_array = query_array / qn
+            similarities = np.dot(embeddings_matrix, query_array.T).flatten()
+            return float(np.max(similarities)) if similarities.size > 0 else 0.0
+        except Exception:
+            return 0.0
         
     def extract_embedding_from_detection(self, detection: Dict) -> Tuple[Dict, Optional[List[float]]]:
         """Extract and validate embedding from detection."""
