@@ -215,7 +215,8 @@ class FacialRecognitionClient:
             "embedding": face_embedding,
             "collection": collection,
             "threshold": threshold,
-            "limit": limit
+            "limit": limit,
+            "images_required":False,
         }
         
         # Add optional fields only if provided
@@ -447,14 +448,29 @@ class FacialRecognitionClient:
             )
             
             embeddings_count = 0
-            if response.get('success', False):
-                data = response.get('data', [])
-                embeddings_count = len(data) if isinstance(data, list) else 0
-                self.logger.info(f"API RESPONSE: Retrieved {embeddings_count} staff embeddings")
+            if response:
+                # Handle both list and dict responses
+                if isinstance(response, list):
+                    # API returned list directly
+                    data = response
+                    embeddings_count = len(data)
+                    self.logger.info(f"API RESPONSE: Retrieved {embeddings_count} staff embeddings (list format)")
+                    # Return in standard format for consistency
+                    return {"success": True, "data": data}
+                elif isinstance(response, dict):
+                    # API returned dict with 'data' key
+                    data = response.get('data', [])
+                    embeddings_count = len(data) if isinstance(data, list) else 0
+                    self.logger.info(f"API RESPONSE: Retrieved {embeddings_count} staff embeddings (dict format)")
+                    return self._handle_response(response)
+                else:
+                    self.logger.error(f"Unexpected response type: {type(response)}")
+                    return {"success": False, "error": f"Unexpected response type: {type(response)}"}
             else:
-                self.logger.warning(f"Failed to get staff embeddings: {response.get('error', 'Unknown error')}")
+                error_msg = response.get('error', 'Unknown error') if isinstance(response, dict) else 'Empty response'
+                self.logger.warning(f"Failed to get staff embeddings: {error_msg}")
+                return {"success": False, "error": error_msg}
             
-            return self._handle_response(response)
         except Exception as e:
             self.logger.error(f"API ERROR: Get all staff embeddings request failed - {e}", exc_info=True)
             return {"success": False, "error": str(e)}
@@ -564,10 +580,10 @@ class FacialRecognitionClient:
     def _handle_response(self, response: Dict[str, Any]) -> Dict[str, Any]:
         """Handle RPC response and errors"""
         try:
-            if response.get("success", True):
+            if response:
                 return response
             else:
-                error_msg = response.get("error", "Unknown RPC error")
+                error_msg = response #.get("error", "Unknown RPC error")
                 self.logger.error(f"RPC Error: {error_msg}", exc_info=True)
                 return {"success": False, "error": error_msg}
         except Exception as e:
