@@ -31,11 +31,31 @@ import numpy as np
 #import torch
 import re
 from matrice_analytics.post_processing.core.config import BaseConfig, AlertConfig, ZoneConfig
+
+# Try to import optional age/gender dependencies (fail gracefully if missing)
+ort = None
+Image = None
+
 try:
-    from PIL import Image
     import onnxruntime as ort
-except:
-    print("Unable to import onnxruntime")
+    from PIL import Image
+    print("✓ Age/Gender dependencies available (onnxruntime, PIL)")
+except ImportError as e:
+    error_msg = str(e)
+    print(f"⚠ Age/Gender dependencies not available: {e}")
+
+    # Check if it's a NumPy version mismatch issue and provide helpful message
+    if "NumPy" in error_msg and ("1.x" in error_msg or "2." in error_msg):
+        print("→ DETECTED: NumPy version mismatch!")
+        print("  onnxruntime was compiled with NumPy 1.x but NumPy 2.x is installed")
+        print("  To fix manually: pip install 'numpy<2' --force-reinstall")
+    else:
+        print("  To enable manually: pip install onnxruntime-gpu pillow")
+
+    print("→ Age/Gender detection will be disabled")
+except Exception as e:
+    print(f"⚠ Error importing Age/Gender dependencies: {e}")
+    print("→ Age/Gender detection will be disabled")
 
 
 def apply_category_mapping(results: Any, index_to_category: Dict[str, str]) -> Any:
@@ -89,9 +109,16 @@ def load_model_from_checkpoint(checkpoint_path,local_path):
     """
     Load a model from checkpoint URL
     """
+    if ort is None:
+        raise RuntimeError(
+            "onnxruntime is not available. Cannot load age/gender detection models.\n"
+            "Please install: pip install onnxruntime-gpu\n"
+            "Or downgrade numpy: pip install 'numpy<2'"
+        )
+
     try:
         print(f"Loading model from checkpoint: {checkpoint_path}")
-        
+
         # Check if checkpoint is a URL
         if checkpoint_path.startswith(('http://', 'https://')):
             # Download checkpoint from URL
@@ -153,10 +180,25 @@ class AgeGenderConfig(BaseConfig):
 
     def __post_init__(self):
         if self.gender_url and self.age_url:
-            self.age_url = load_model_from_checkpoint(self.age_url, "age_detection_prod_model.onnx")
-            self.gender_url = load_model_from_checkpoint(self.gender_url, "gender_detection_prod_model.onnx")
+            try:
+                self.age_url = load_model_from_checkpoint(self.age_url, "age_detection_prod_model.onnx")
+                self.gender_url = load_model_from_checkpoint(self.gender_url, "gender_detection_prod_model.onnx")
+                print("✓ Age and Gender models loaded successfully")
+            except RuntimeError as e:
+                print(f"✗ Failed to load Age/Gender models: {e}")
+                print("→ Age/Gender detection will be disabled")
+                self.age_url = None
+                self.gender_url = None
+            except Exception as e:
+                print(f"✗ Unexpected error loading Age/Gender models: {e}")
+                import traceback
+                traceback.print_exc()
+                self.age_url = None
+                self.gender_url = None
         else:
-            raise ValueError("Age and Gender model URL must be passed!")
+            print("⚠ Age and Gender model URLs not provided - detection will be disabled")
+            self.age_url = None
+            self.gender_url = None
         
 
 class AgeGenderUseCase(BaseProcessor):
