@@ -509,7 +509,7 @@ class LicensePlateMonitorUseCase(BaseProcessor):
         
         # Initialize plate logger (optional, only used if lpr_server_id is provided)
         self.plate_logger: Optional[LicensePlateMonitorLogger] = None
-        self._logging_enabled = True
+        self._logging_enabled = False
         self._plate_logger_initialized = False  # Track if plate logger has been initialized
         
 
@@ -575,7 +575,7 @@ class LicensePlateMonitorUseCase(BaseProcessor):
         print(f"[LP_LOGGING] Starting plate logging check - detections count: {len(detections)}")
         self.logger.info(f"[LP_LOGGING] Starting plate logging check - detections count: {len(detections)}")
         self.logger.info(f"[LP_LOGGING] Logging enabled: {self._logging_enabled}, Plate logger exists: {self.plate_logger is not None}, Stream info exists: {stream_info is not None}")
-        
+        self._logging_enabled=False  #TODO: REMOVE IT LATER
         if not self._logging_enabled:
             print("[LP_LOGGING] Plate logging is DISABLED")
             self.logger.warning("[LP_LOGGING] Plate logging is DISABLED - logging_enabled flag is False")
